processor — squidasm 0.0.2 documentation

# processor

The abstract class `NetSquidProcessor` can execute a given (parsed) NetQASM subroutine using NetSquid. The method `get_next_subroutine()` needs to be overriden to define how the processor should fetch the next subroutine to execute. By default no quantum operations are actually performed but also needs to be overriden.

The class `FromStringNetSquidProcessor` implementes the method `get_next_subroutine()` by simply getting subroutines from a queue of subroutines submitted by `put_subroutine()`.

class `squidasm.executioner.` `PendingEPRResponse`(response, epr_cmd_data, pair_index)
  `epr_cmd_data`

    Alias for field number 1

  `pair_index`

    Alias for field number 2

  `response`

    Alias for field number 0

class `squidasm.executioner.` `NetSquidExecutioner`(node, name=None, network_stack=None, instr_log_dir=None)
  `NS_INSTR_MAPPING` = {<Instruction.INIT: 2>: Instruction: initialization_op, <Instruction.X: 20>: Instruction: x_gate, <Instruction.Y: 21>: Instruction: y_gate, <Instruction.Z: 22>: Instruction: z_gate, <Instruction.H: 23>: Instruction: h_gate, <Instruction.K: 25>: Instruction: k_gate, <Instruction.S: 24>: Instruction: s_gate, <Instruction.T: 26>: Instruction: t_gate, <Instruction.ROT_X: 27>: Instruction: x_rot_gate, <Instruction.ROT_Y: 28>: Instruction: y_rot_gate, <Instruction.ROT_Z: 29>: Instruction: z_rot_gate, <Instruction.CNOT: 30>: Instruction: cnot_gate, <Instruction.CPHASE: 31>: Instruction: cz_gate}
  `__init__`(node, name=None, network_stack=None, instr_log_dir=None)

    Executes a NetQASM using a NetSquid quantum processor to execute quantum instructions

  property `qdevice`